@@ -30,11 +30,11 @@ theme_natriskbg <- function(base_theme, base_size = 20, base_family = "") {
       panel.background = element_rect(fill = plotbg, colour = "transparent"),
       panel.grid.major = element_blank(),
       panel.grid.minor = element_blank(),
-      panel.margin     = unit(0, "lines"),
+      panel.spacing    = unit(0, "lines"),
       panel.border     = element_blank(),
       plot.background  = element_rect(fill = plotbg, colour = "transparent"),
       plot.title       = element_blank(),
       plot.margin      = unit(c(0, 0, 0, 0), "lines")
     )
   
-}
\ No newline at end of file
+}
